==> libcommons-codec-java_1.15.orig.tar.xz: commons-codec-rel-commons-codec-1.15/src/test/java/org/apache/commons/codec/CharsetsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.commons.codec;

import java.nio.charset.Charset;

import org.junit.Assert;
import org.junit.Test;

/**
 * Sanity checks for {@link Charsets}.
 *
 */
public class CharsetsTest {

    @Test
    public void testToCharset() {
        Assert.assertEquals(Charset.defaultCharset(), Charsets.toCharset((String) null));
        Assert.assertEquals(Charset.defaultCharset(), Charsets.toCharset((Charset) null));
        Assert.assertEquals(Charset.defaultCharset(), Charsets.toCharset(Charset.defaultCharset()));
        Assert.assertEquals(Charset.forName("UTF-8"), Charsets.toCharset(Charset.forName("UTF-8")));
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testIso8859_1() {
        Assert.assertEquals("ISO-8859-1", Charsets.ISO_8859_1.name());
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testUsAscii() {
        Assert.assertEquals("US-ASCII", Charsets.US_ASCII.name());
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testUtf16() {
        Assert.assertEquals("UTF-16", Charsets.UTF_16.name());
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testUtf16Be() {
        Assert.assertEquals("UTF-16BE", Charsets.UTF_16BE.name());
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testUtf16Le() {
        Assert.assertEquals("UTF-16LE", Charsets.UTF_16LE.name());
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testUtf8() {
        Assert.assertEquals("UTF-8", Charsets.UTF_8.name());
    }

}

==> libcommons-codec-java_1.16.0.orig.tar.xz: commons-codec-rel-commons-codec-1.16.0/src/test/java/org/apache/commons/codec/CharsetsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.commons.codec;

import static org.junit.jupiter.api.Assertions.assertEquals;

import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;

import org.junit.jupiter.api.Test;

/**
 * Sanity checks for {@link Charsets}.
 */
public class CharsetsTest {

    @Test
    public void testToCharset() {
        assertEquals(Charset.defaultCharset(), Charsets.toCharset((String) null));
        assertEquals(Charset.defaultCharset(), Charsets.toCharset((Charset) null));
        assertEquals(Charset.defaultCharset(), Charsets.toCharset(Charset.defaultCharset()));
        assertEquals(StandardCharsets.UTF_8, Charsets.toCharset(StandardCharsets.UTF_8));
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testIso8859_1() {
        assertEquals("ISO-8859-1", Charsets.ISO_8859_1.name());
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testUsAscii() {
        assertEquals("US-ASCII", Charsets.US_ASCII.name());
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testUtf16() {
        assertEquals("UTF-16", Charsets.UTF_16.name());
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testUtf16Be() {
        assertEquals("UTF-16BE", Charsets.UTF_16BE.name());
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testUtf16Le() {
        assertEquals("UTF-16LE", Charsets.UTF_16LE.name());
    }

    @SuppressWarnings("deprecation")
    @Test
    public void testUtf8() {
        assertEquals("UTF-8", Charsets.UTF_8.name());
    }

}
